<?php

/*
Home Site Maker, the websites factory.
Copyright (C) 2004 Marcos Martinez Jimenez

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

Marcos Martinez Jimenez
marcos@assl-site.net
http://homesitemaker.no-ip.org
Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain
*/

//---------- ./homesite/help.php ----------

$TEXT001="Panel de Control";
$TEXT002="Usuaris";
$TEXT003="Configuraci&oacute;";
$TEXT004="Estil";
$TEXT005="Cr&egrave;ditos";
$TEXT007="No t'has validat com un usuari autoritzat !<br>".
         "El Panel de Control es nom&ecute;s per usuaris enregistrats<br>amb privilegis d'administrador.<br>".
         "Probablement no hauries d'estar aqu&iacute;.";

?>
